sirenapp_flutter_inbox library

Classes

ApiResponse
Class representing an API response.
AvatarData
Class representing the data structure of an avatar.
BadgeColors
Custom theme colors to configure icon badge
BadgeStyle
Properties for configuring the appearance of the badge.
CardColors
Custom theme colors to configure the appearance inbox list item.
CardParams
Properties for configuring the appearance of the notification card.
CardStyle
CategoryFilterColors
CategoryFilterParams
Properties for configuring the appearance and behavior of the category dropdown.
CategoryFilterStyles
Properties for configuring the appearance of the category dropdown.
ClearAllIconStyle
ContainerStyle
Properties to configure the style of container
CustomStyles
Style properties for customizing the appearance of various UI elements in the Siren theme.
CustomThemeColors
Custom theme colors to configure the appearance of UI elements.
DefaultIconStyle
Default styles for the Siren notification icon.
DeleteIconStyle
DioResponse
Represents a response from Dio HTTP client.
FilterColors
Custom theme colors to configure the appearance of filters
FilterParams
FilterStyles
Styles for customizing the appearance of filters
HeaderParams
Properties for configuring the appearance of the notification window app bar.
HideTabMargin
InboxHeaderColors
Custom theme colors to configure the inbox header
InboxHeaderStyle
Properties to configure the style of default inbox header
MessageData
Class representing the data structure of a message.
MetaResponse
Represents metadata associated with an API response.
NotificationIconStyle
Customizable style for the Siren notification icon.
NotificationType
Class representing the data structure of a notification.
Siren
SirenErrorType
Represents details of an API error.
SirenInbox
Widget for displaying an inbox of notifications.
SirenInboxIcon
Widget representing the inbox icon.
SirenProvider
Provides access to the Siren SDK functionalities.
StreamResponse
Class representing a response from a stream.
TabColors
Colors for customizing the appearance of the tab bar.
TabItem
Represents an individual tab item.
TabParams
Properties for configuring the appearance and behavior of the tab bar.
TabStyles
Styles for customizing the appearance of the tab bar.
TimerIconStyle